%define              with_system_ca_cert_file    1
%define              system_ca_cert_file         %{_sysconfdir}/pki/tls/cert.pem

%define              main_ver        0.5.99.66
%define              strtag          cvs070110

%define              vendor_rel      4
%define              pre_release     1

%if %{pre_release}
%define              rel             0.%{vendor_rel}.%{strtag}%{?dist}
%else
%define              rel             %{vendor_rel}%{?dist}
%endif

Summary:             A GTK+ 2ch.net BBS Browser
Name:                ochusha
Version:             %{main_ver}
Release:             %{rel}.2
URL:                 http://ochusha.sourceforge.jp/
%if %{pre_release}
Source:              %{name}-%{main_ver}-%{strtag}.tar.bz2
%else
Source:              http://keihanna.dl.sourceforge.jp/ochusha/16560/%{name}-%{version}.tar.bz2
%endif
Patch0:              ochusha-0.5.99.66-cvs070110-disable-lock-check.patch
Patch1:              ochusha-0.5.99.66-cvs070110-g++43-missing-headers.patch
License:             BSD
Group:               Applications/Internet
BuildRoot:           %{_tmppath}/%{name}-%{version}-root-%(%{__id_u} -n)

Requires:            fonts-japanese
Requires:            %{system_ca_cert_file}
Requires:            xdg-utils

BuildRequires:       libtool
BuildRequires:       gettext
BuildRequires:       libSM-devel
BuildRequires:       libXt-devel
BuildRequires:       libxml2-devel
BuildRequires:       gtk2-devel
BuildRequires:       openssl-devel
BuildRequires:       desktop-file-utils

%description
The ochusha is BBS, especially 2ch.net, browser with GUI.
It uses the GTK+ toolkit for all of its interface needs.
The ochusha offers a sort of features such as multi-level
popup view of `response's, embeded and popup view of
images that helps users to interact with BBSs.

%prep
%if %{pre_release}
%setup -q -n %{name}-%{main_ver}-%{strtag}
%else
%setup -q
%endif
%patch0 -p1 -b .lock
%patch1 -p1 -b .gcc43

# change desktop entry to use png file at %%{icondir}.
%{__sed} -i -e 's|Icon.*$|Icon=ochusha48.png|' ochusha/ochusha.desktop.in

# set htmlview as a default browser
%{__sed} -i -e 's|firefox|xdg-open|' ochusha/preferences.cc

%build
sh autogen.sh

%configure \
%if %{with_system_ca_cert_file}
   --with-ca-cert-file=%{system_ca_cert_file}
%endif

%{__make} %{?_smp_flags}

%install
%{__rm} -rf %{buildroot}
%{__make} DESTDIR=%{buildroot} install

# find lang
%find_lang %{name}
%find_lang %{name}-properties

%{__cat} %{name}.lang %{name}-properties.lang > all.lang

# Licenses.
if test -f "oniguruma/COPYING"; then
  %{__mv} oniguruma/COPYING oniguruma/COPYING.oniguruma
fi
if test -f "libochushagtk_lgpl/COPYING"; then
  %{__mv} libochushagtk_lgpl/COPYING libochushagtk_lgpl/COPYING.libochushagtk_lgpl
fi

# remove unneeded files
%{__rm} -f %{buildroot}/%{_libdir}/*.a
%{__rm} -f %{buildroot}/%{_libdir}/*.la
%{__rm} -f %{buildroot}/%{_libdir}/*.so
%if %{with_system_ca_cert_file}
%{__rm} -f %{buildroot}/%{_datadir}/%{name}/ca-bundle.crt
%{__rm} -f %{buildroot}/%{_datadir}/%{name}/ochusha-gtkrc*
%endif

# install desktop file and delete original
%{__mkdir_p} %{buildroot}%{_datadir}/applications
%{__sed} -i -e 's|ochusha48\.png|ochusha48|' \
      %{buildroot}%{_datadir}/ochusha/%{name}.desktop
desktop-file-install \
      --delete-original \
      --vendor fedora \
      --remove-category Application \
      --dir %{buildroot}%{_datadir}/applications \
      %{buildroot}%{_datadir}/ochusha/%{name}.desktop

# link icon to icondir according to Icon Theme Specification.
%{__mkdir_p} %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/
%{__ln_s} -f ../../../../ochusha/ochusha48.png \
	%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/

# change documents' encoding to UTF-8.
change_encoding(){
   CODE=$1
   shift
   for f in $* ; do
      mv ${f} ${f}.tmp
      iconv -f $CODE -t UTF-8 ${f}.tmp > ${f} && rm -f ${f}.tmp || \
         mv ${f}.tmp ${f}
   done
}

change_encoding EUCJP \
   BUGS ChangeLog NEWS README TODO \
   ochusha/ochusha-gtkrc.gray

%clean
%{__rm} -rf %{buildroot}

%post
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :

%postun
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :

%files -f all.lang
%defattr(-,root,root)
%doc ACKNOWLEDGEMENT AUTHORS BUGS COPYING ChangeLog NEWS README TODO
%doc ochusha/ochusha-gtkrc.*
%doc oniguruma/COPYING.oniguruma
%doc libochushagtk_lgpl/COPYING.libochushagtk_lgpl

%{_bindir}/ochusha
%{_datadir}/%{name}/*
%{_datadir}/applications/fedora-%{name}.desktop
%dir %{_datadir}/%{name}
%{_libdir}/lib*
%{_mandir}/man1/%{name}.1*

%{_datadir}/icons/hicolor/48x48/apps/*.png

%changelog
* Sat Feb  9 2008 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp>
- Rebuild against gcc43

* Sun Jan  6 2008 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.99.66-0.4.cvs070110
- Misc fixes for g++43.

* Wed Dec  5 2007 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.99.66-0.3.cvs070110
- Fix icon path in desktop file for desktop-file-utils 0.14+

* Tue Dec  4 2007 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.99.66-0.2.cvs070110.dist.3
- Rebuild for new openssl (on rawhide)

* Wed Apr 22 2007 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.99.66-0.2.cvs070110.dist.2
- Mass rebuild (buildID or binutils issue)

* Tue Apr 17 2007 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.99.66-0.2.cvs070110
- Disable lock checking for now.

* Wed Jan 10 2007 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.99.66-0.1.cvs070110
- cvs 070110 (19:20 JST)

* Sat Nov 18 2006 <fuyu@users.sourceforge.jp>
- COPYING files of oniguruma and libochushagtk_lgpl will be installed
  as COPYING.oniguruma and COPYING.libochushagtk_lgpl.

* Fri Nov 03 2006 <fuyu@users.sourceforge.jp> 0.5.99.62-1
- Version down.
- Specify the CA certificate file bundled within openssl package.

* Mon Sep 19 2006 <fuyu@users.sourceforge.jp> 0.6-1
- Version up.
- Change request fields for gtk+-2.6 and libxml2-2.6.

* Sat Aug 26 2006 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.8.2-3
- Install (link) icon to the usual directory and use 
  cache updating method.

* Sat Aug 26 2006 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.8.2-2
- Explicitly require Japanese fonts.

* Wed Aug 23 2006 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> 0.5.8.2-1
- Import to Fedora Extras.
- Add two patch (from 2ch BBS ochusha thread).
- Remove unnecessary .so files and desktop file installed on wrong
  location.
- Use desktop-file-install, update-desktop-database
- Add some missing BR.
- Change documents' encoding.

* Wed Dec 29 2004 <fuyu@users.sourceforge.jp> 0.5.7.1-1
- Version up.
- The ochusha.spec file is polished according to anonymous people's voice.

* Wed Nov 25 2004 <fuyu@users.sourceforge.jp> 0.5.7-1
- Version up.
- The ochusha.spec file is polished according to Matchy's advise.

* Sat Nov 13 2004 <fuyu@users.sourceforge.jp> 0.5.6-1
- Version up.
- The ochusha.spec file is now generated automatically.
- Some hardcoded build/install rules are replaced with common macros.
- Post install/uninstall rules are modified to link/unlink the
  ochusha.desktop file for menu.

* Sat Jul 03 2004 <yuhei@users.sourceforge.jp> 0.5.5-1
- Version up.

* Sun Jun 20 2004 <yuhei@users.sourceforge.jp> 0.5.4.10-1
- Version up.

* Wed Jun 16 2004 <yuhei@users.sourceforge.jp> 0.5.4.9-1
- Version up.

* Tue Jun 15 2004 <yuhei@users.sourceforge.jp> 0.5.4.8-1
- Version up.

* Mon Jun 14 2004 <yuhei@users.sourceforge.jp> 0.5.4.7-1
- Version up.

* Sun Jun 13 2004 <yuhei@users.sourceforge.jp> 0.5.4.5-1
- Version up.

* Sat Jun 12 2004 <yuhei@users.sourceforge.jp> 0.5.4.4-1
- Version up.

* Sun Jun 06 2004 <yuhei@users.sourceforge.jp> 0.5.4.3-1
- Version up.

* Mon May 24 2004 <yuhei@users.sourceforge.jp> 0.5.4.2-1
- Version up.

* Mon May 17 2004 <yuhei@users.sourceforge.jp> 0.5.4.1-1
- Version up.

* Sun May 02 2004 <yuhei@users.sourceforge.jp> 0.5.2-1
- Version up.

* Sat Apr 10 2004 <yuhei@users.sourceforge.jp> 0.5.1-1
- Version up.
- Added manfile to filelist.
- Added mandir option to configure script.

* Mon Mar 01 2004 <yuhei@users.sourceforge.jp> 0.5-1
- Version up.
- Changed filelist.

* Wed Jan 28 2004 <yuhei@users.sourceforge.jp> 0.4.10.3-1
- Version up.

* Fri Jan 23 2004 <yuhei@users.sourceforge.jp> 0.4.10.1-1
- Version up.

* Wed Jan 21 2004 <yuhei@users.sourceforge.jp> 0.4.10-1
- Version up.

* Sun Jan 18 2004 <yuhei@users.sourceforge.jp> 0.4.9.7-1
- Version up.

* Sat Jan 17 2004 <yuhei@users.sourceforge.jp> 0.4.9.6-1
- Version up.

* Fri Jan 16 2004 <yuhei@users.sourceforge.jp> 0.4.9.5-1
- Version up.

* Wed Jan 14 2004 <yuhei@users.sourceforge.jp> 0.4.9.4-1
- Version up.

* Wed Jan 14 2004 <yuhei@users.sourceforge.jp> 0.4.9.3-1
- Version up.

* Tue Jan 13 2004 <yuhei@users.sourceforge.jp> 0.4.9.2-1
- Version up.

* Mon Jan 12 2004 <yuhei@users.sourceforge.jp> 0.4.9.1-1
- Version up.

* Tue Jan 01 2004 <yuhei@users.sourceforge.jp> 0.4.8.2-1
- Version up.

* Wed Dec 31 2003 <yuhei@users.sourceforge.jp> 0.4.8.1-1
- Version up.

* Tue Dec 30 2003 <yuhei@users.sourceforge.jp> 0.4.8-1
- Version up.
- Added files about libtsengine.
- Added ochusha-init.scm file.
- Added to run ldconfig when (un)installing. 

* Mon Dec 29 2003 <yuhei@users.sourceforge.jp> 0.4.7.1-1
- Version up.

* Wed Dec 24 2003 <yuhei@users.sourceforge.jp> 0.4.7-1
- Version up.

* Mon Dec 22 2003 <yuhei@users.sourceforge.jp> 0.4.6-1
- Version up.

* Sun Dec 21 2003 <yuhei@users.sourceforge.jp> 0.4.5.10-1
- Version up.

* Fri Dec 19 2003 <yuhei@users.sourceforge.jp> 0.4.5.7-1
- Version up.

* Tue Dec 16 2003 <yuhei@users.sourceforge.jp> 0.4.5.6-1
- Version up.

* Tue Dec 16 2003 <yuhei@users.sourceforge.jp> 0.4.5.5-1
- Version up.

* Sun Dec 14 2003 <yuhei@users.sourceforge.jp> 0.4.5.4-1
- Version up.

* Sat Dec 13 2003 <yuhei@users.sourceforge.jp> 0.4.5.3-1
- Version up.

* Mon Dec 09 2003 <yuhei@users.sourceforge.jp> 0.4.5.1-1
- Version up.

* Sat Dec 06 2003 <yuhei@users.sourceforge.jp> 0.4.5-1
- Version up.
- Added png icon file. 
- Added gtkrc file.

* Thu Nov 27 2003 <yuhei@users.sourceforge.jp> 0.4.4.8-1
- Added xpm icon file.
- Version up.

* Fri Nov 21 2003 <yuhei@users.sourceforge.jp> 0.4.4.3-1
- Version up.

* Fri Nov 14 2003 <yuhei@users.sourceforge.jp> 0.4.4.2-1
- Version up.
- Added some libraries. 

* Mon Jun 23 2003 <yuhei@users.sourceforge.jp> 0.4.3.6-1
- Version up.

* Wed Jun 11 2003 <yuhei@users.sourceforge.jp> 0.4.3.4-1
- Version up.
- changed prefix enviromental valuable.
- changed URL.

* Mon May 19 2003 <yuhei@users.sourceforge.jp> 0.4.3.3-1
- Version up.

* Mon May 12 2003 <yuhei@users.sourceforge.jp> 0.4.3.2-1
- Version up.
- Fixed Group.

* Mon May 12 2003 <yuhei@users.sourceforge.jp> 0.4.2.1-1
- Initial build.
